home | help
GMX-GENION(1)			     GROMACS			   GMX-GENION(1)

NAME
     gmx-genion - Generate monoatomic ions on energetically favorable positions

SYNOPSIS
	gmx genion [-s [<.tpr>]] [-n [<.ndx>]] [-p [<.top>]]
		   [-o [<.gro/.g96/...>]] [-np <int>] [-pname <string>]
		   [-pq <int>] [-nn <int>] [-nname <string>] [-nq <int>]
		   [-rmin <real>] [-seed <int>] [-conc <real>] [-[no]neutral]

DESCRIPTION
     gmx  genion  randomly replaces solvent molecules with monoatomic ions.  The
     group of solvent molecules should be continuous and  all  molecules  should
     have  the	same  number of atoms.	The user should add the ion molecules to
     the topology file or use the -p option to automatically modify  the  topol-
     ogy.

     The  ion  molecule type, residue and atom names in all force fields are the
     capitalized element names without sign. This molecule name should be  given
     with -pname or -nname, and the [molecules] section of your topology updated
     accordingly, either by hand or with -p. Do not use an atom name instead!

     Ions  which  can  have  multiple  charge states get the multiplicity added,
     without sign, for the uncommon states only.

     For larger ions, e.g. sulfate we recommended using gmx insert-molecules.

OPTIONS
     Options to specify input files:

     -s [<.tpr>] (topol.tpr)
	    Portable xdr run input file

     -n [<.ndx>] (index.ndx) (Optional)
	    Index file

     Options to specify input/output files:

     -p [<.top>] (topol.top) (Optional)
	    Topology file

     Options to specify output files:

     -o [<.gro/.g96/...>] (out.gro)
	    Structure file: gro g96 pdb brk ent esp

     Other options:

     -np <int> (0)
	    Number of positive ions

     -pname <string> (NA)
	    Name of the positive ion

     -pq <int> (1)
	    Charge of the positive ion

     -nn <int> (0)
	    Number of negative ions

     -nname <string> (CL)
	    Name of the negative ion

     -nq <int> (-1)
	    Charge of the negative ion

     -rmin <real> (0.6)
	    Minimum distance between ions and non-solvent

     -seed <int> (0)
	    Seed for random number generator (0 means generate)

     -conc <real> (0)
	    Specify salt concentration (mol/liter).  This  will  add  sufficient
	    ions to reach up to the specified concentration as computed from the
	    volume of the cell in the input .tpr file. Overrides the -np and -nn
	    options.

     -[no]neutral (no)
	    This  option  will	add  enough ions to neutralize the system. These
	    ions are added on top of those specified with -np/-nn or -conc.

KNOWN ISSUES
     * If you specify a salt concentration existing ions are not taken into  ac-
       count. In effect you therefore specify the amount of salt to be added.

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			   GMX-GENION(1)

home | help